@@ -35,6 +35,13 @@ def main(argv):
         '-f', '--overwrite', action='store_true',
         help='Overwrite existing hooks / remove migration mode.',
     )
+    install_parser.add_argument(
+        '--install-hooks', action='store_true',
+        help=(
+            'Whether to install hook environments for all environments '
+            'in the config file.'
+        ),
+    )
 
     subparsers.add_parser('uninstall', help='Uninstall the pre-commit script.')
 
@@ -70,10 +77,18 @@ def main(argv):
         argv = ['run']
     args = parser.parse_args(argv)
 
+    if args.command == 'help':
+        if args.help_cmd:
+            parser.parse_args([args.help_cmd, '--help'])
+        else:
+            parser.parse_args(['--help'])
+
     runner = Runner.create()
 
     if args.command == 'install':
-        return install(runner, overwrite=args.overwrite)
+        return install(
+            runner, overwrite=args.overwrite, hooks=args.install_hooks,
+        )
     elif args.command == 'uninstall':
         return uninstall(runner)
     elif args.command == 'clean':
@@ -82,11 +97,6 @@ def main(argv):
         return autoupdate(runner)
     elif args.command == 'run':
         return run(runner, args)
-    elif args.command == 'help':
-        if args.help_cmd:
-            parser.parse_args([args.help_cmd, '--help'])
-        else:
-            parser.parse_args(['--help'])
     else:
         raise NotImplementedError(
             'Command {0} not implemented.'.format(args.command)
