@@ -2,10 +2,14 @@ from __future__ import unicode_literals
 
 import contextlib
 import functools
+import hashlib
 import os
 import os.path
+import pkg_resources
 import shutil
 import sys
+import tarfile
+import tempfile
 
 
 def memoize_by_cwd(func):
@@ -56,3 +60,40 @@ def noop_context():
 
 def shell_escape(arg):
     return "'" + arg.replace("'", "'\"'\"'".strip()) + "'"
+
+
+def hex_md5(s):
+    """Hexdigest an md5 of the string.
+
+    :param text s:
+    """
+    return hashlib.md5(s.encode('utf-8')).hexdigest()
+
+
+@contextlib.contextmanager
+def tarfile_open(*args, **kwargs):
+    """Compatibility layer because python2.6"""
+    tf = tarfile.open(*args, **kwargs)
+    try:
+        yield tf
+    finally:
+        tf.close()
+
+
+@contextlib.contextmanager
+def tmpdir():
+    """Contextmanager to create a temporary directory.  It will be cleaned up
+    afterwards.
+    """
+    tempdir = tempfile.mkdtemp()
+    try:
+        yield tempdir
+    finally:
+        shutil.rmtree(tempdir)
+
+
+def resource_filename(filename):
+    return pkg_resources.resource_filename(
+        'pre_commit',
+        os.path.join('resources', filename),
+    )
